@@ -31,7 +31,7 @@ class ScrapflyError(Exception):
     def __init__(
         self,
         message: str,
-        code: int,
+        code: str,
         http_status_code: int,
         resource: Optional[str]=None,
         is_retryable: bool = False,
@@ -71,6 +71,10 @@ class EncoderError(BaseException):
         return self.content
 
 
+class ExtraUsageForbidden(ScrapflyError):
+    pass
+
+
 class HttpError(ScrapflyError):
 
     def __init__(self, request:Request, response:Optional[Response]=None, **kwargs):
